Stable product identity and version values shared by Hyphae surfaces.
Structs
- Version
Info - Product version information that can be reported without opening a data directory.
Constants
- API_
VERSION - Current public HTTP API version.
- DISK_
FORMAT_ VERSION - Current on-disk format version.
- PRODUCT_
NAME - Canonical product and executable name.
Functions
- current_
version - Returns the version information compiled into this build.